;
; COMMANDS.INC
;
;----------------------------------------------------------------------------;
;
; Comment the following line if you use the Norton Commander rather than
; the Volcov Commander. With the Norton Commander this program will work
; only if both panels are on the screen. VCFlags are not used in that case.

VC	EQU	True

;--------------------------- The Command Table ------------------------------
;
; Syntax:
;
;
;   Entry    ScanCode, [KbdFlags], [VCFlags] - Start new macro definition
;     Key    AsciiCode			     - ASCII key code to send
;     String Str			     - Text string to send
;
;   Disk     KbdFlags, Code	     - Special entry for disks switching
;
; By default int the Entry directive KbdFlags equals 0 and VCFlags
; equals vcDontCare
;
; One macro can contain as many Key and String definitions as you wish.
; Disk macro can not contain neither Key nor String definition.
;
; In the one Key directive the angle brackets can be used to group commands,
; for example:
;   Key <kbF8, kbEnter>
; Note: That is equivalent to the sequence:
;   Key kbF8
;   Key kbEnter
;
; For scan and ASCII codes see the file KEYS.INC
;
;----------------------------------------------------------------------------

; Keyboard flag masks

kfRightShift	EQU	BYTE PTR 01h
kfLeftShift	EQU	BYTE PTR 02h
kfShift 	EQU	BYTE PTR 30h		; any shift
kfCtrl		EQU	BYTE PTR 04h
kfAlt		EQU	BYTE PTR 08h
;
; Note: To use flags combination use the following syntax:
;   <Flag1 + Flag2 + Flag3>, for example <kfShift + kfAlt>
;
;----------------------------------------------------------------------------

; VC flag masks, a macro will work only if appropriate flags are set.

vcPanelsON	EQU	BYTE PTR 01h
vcPanelsOFF	EQU	BYTE PTR 02h
vcDontCare	EQU	BYTE PTR 03h

;----------------------------------------------------------------------------

; Disk switchings
Disk	<kfCtrl + kfLeftShift>, kbAltF1
Disk	<kfCtrl + kfRightShift>, kbAltF2

Disk	<kfAlt + kfLeftShift>, kbAltF2
Disk	<kfAlt + kfRightShift>, kbAltF1

Entry	scGrayPlus,, vcPanelsON 	; Select all with prompt
  Key	kbGrayPlus
  String *.*
  Key	kbHome

Entry	scGrayPlus, kfAlt		; Select previous with prompt
  Key	kbGrayPlus

Entry	scGrayPlus, kfCtrl, vcPanelsON	; Quick select all
  Key	kbGrayPlus
  String *.*
  Key	kbEnter

Entry	scGrayMinus,, vcPanelsON	; UnSelect all with prompt
  Key	kbGrayMinus
  String *.*
  Key	kbHome

Entry	scGrayMinus, kfCtrl, vcPanelsON ; Quick unselect all
  Key	kbGrayMinus
  String *.*
  Key	kbEnter

Entry	scGrayMinus, kfAlt		; UnSelect previous with prompt
  Key	kbGrayMinus

Entry	scAster,, vcPanelsON		; Toggle all without prompt
  Key	kbGrayAster
  String *.*
  Key	kbEnter

Entry	scPgDn, kfShift, vcPanelsON	; Toggle all without prompt
  Key	kbGrayAster
  String *.*
  Key	kbEnter

Entry	scPgUp, kfShift, vcPanelsON	; the same
  Key	kbGrayAster
  String *.*
  Key	kbEnter

Entry	scAster, kfAlt			; Toggle selection with prompt
  Key	kbGrayAster

; Note: To make the following macro work unckeck the Clear Keyboard Buffer
; options in the Advanced Options Setup.

Entry	scDel, kfCtrl, vcPAnelsON	; Delete without a prompt (Beware!)
  Key	<kbF8, kbEnter>

Entry	scDel, <kfCtrl + kfShift>, vcPanelsON ; Delete a single file without
  Key	<kbCtrlF8, kbEnter>		      ; a prompt (Beware!)

; The following commands are to select files using Shift + Up or Down arrows
; and also make Ins key work with autorepeat.
; Note: You have to uncheck the Ins Moves Down option in the Configuration
; Menu.

Entry	scDown, kfShift 		; Select and move down
  Key	<kbIns, kbDown>

Entry	scUp, kfShift			; Select and move up
  Key	<kbIns, kbUp>

Entry	scIns				; Simulated Ins Moves Down
  Key	<kbIns, kbDown>

Entry	scIns, kfShift			; Select with Ins and move up
  Key	<kbIns, kbUp>

Entry	scLeft, kfShift 		; Select and stay
  Key	kbIns

Entry	scRight, kfShift		; Select and stay
  Key	kbIns

Entry	scLeft, kfAlt			; Move the cursor left
  Key	kbCtrlS

Entry	scRight, kfAlt			; Move the cursor right
  Key	kbCtrlD

Entry	scHome, kfAlt			; Move the cursor to the start of line
  Key	kbCtrlHome

Entry	scEnd, kfAlt			; Move the cursor to the end of line
  Key	kbCtrlEnd

Entry	scUp, kfAlt			; Previous command
  Key	kbCtrlE

Entry	scDown, kfAlt			; Next command
  Key	kbCtrlX

Entry	scDown, kfCtrl			; History List
  Key	kbAltF8

Entry	29h, kfCtrl			; Ctrl~ - lear the screen
  Key	<kbEsc>
  String cls
  Key	<kbEnter>

Entry	scN, <kfCtrl+kfAlt>		; Sort by name
  Key	<kbF9, kbEnter>
  String N

Entry	scS, <kfCtrl+kfAlt>		; Sort by size
  Key	<kbF9, kbEnter>
  String S

Entry	scT, <kfCtrl+kfAlt>		; Sort by time
  Key	<kbF9, kbEnter>
  String M
  
Entry	scM, <kfCtrl+kfAlt>		; Sort by time
  Key	<kbF9, kbEnter>
  String M

Entry	scX, <kfCtrl+kfAlt>		; Sort by extension
  Key	<kbF9, kbEnter>
  String X

Entry	scF10, kfCtrl			; Quick exit without asking
  Key	<kbF10, kbEnter>

Entry	scBack, kfShift 		; Call external editor
  Key	kbF4

Entry	scEnter, kfShift		; View a file
  Key	kbAltF3

Entry	scF7, kfAlt			; Move to '*' in the Find File dialog
  Key	<kbAltF7, kbRight>

Entry	scUp, kfCtrl			; Panels ON/OFF
  Key	kbCtrlO

; My own stuff --------------------------------------------------------------

Entry	scF1,,vcPanelsON		; Call Tech Help from the User Menu
  Key	<kbF2, kbF1>

Entry	scBack, kfAlt			; Call my favourite editor
  Key	<kbEsc>
  String te.exe
  Key	<kbEnter>

Entry	scG, kfCtrl			; Call the GoTo sub-menu
  Key	<kbF2>
  String G

Entry 	29h, kfAlt			; Call a batch to delete *.BAK, etc.
  Key	kbEsc
  String DelTrash
  Key	kbEnter

Entry	scZ, <kfShift+kfAlt+kfCtrl>	; Call the archivers' menu
  Key	<kbF2, kbF3>

Entry	scP, <kfShift+kfAlt+kfCtrl>	; Call my telephone directory
  Key	kbF2
  String P

;---------------------------------------------------------------------------
